@@ -8,7 +8,7 @@ from tornado import gen
 from .cortx_authenticator import CortxAuthenticator
 # from .utils import (MultiPartUploadHelper,_get_key,_get_path, _get_full_path,_get_type,_get_format,_get_type_from_key)
 from .utils import (
-    _run_sync_in_new_thread,MultiPartUploadHelper,_check_directory_exists,_check_file_exists,_get,_save,_delete,_rename,_new_untitled,_new,_copy,_create_checkpoint,_restore_checkpoint,_list_checkpoints,_delete_checkpoint
+    _run_sync,MultiPartUploadHelper,_check_directory_exists,_check_file_exists,_get_model,_save_model,_delete,_rename_notebook,_new_untitled_notebook,_new,_copy,_create_new_checkpoint,_restore_checkpoint,_list_all_checkpoints,_delete_checkpoint
     )
 from .utils import *
 import json 
@@ -63,7 +63,7 @@ class CortxJupyter(ContentsManager):
         def dir_exists_async():
             return (yield _check_directory_exists(self._config(), path))
 
-        return _run_sync_in_new_thread(dir_exists_async)
+        return _run_sync(dir_exists_async)
 
     def file_exists(self, path):
 
@@ -71,20 +71,20 @@ class CortxJupyter(ContentsManager):
         def file_exists_async():
             return (yield _check_file_exists(self._config(), path))
 
-        return _run_sync_in_new_thread(file_exists_async)
+        return _run_sync(file_exists_async)
 
     def get(self, path, content=True, type=None, format=None):
 
         @gen.coroutine
         def get_async():
-            return (yield _get(self._config(), path, content, type, format))
+            return (yield _get_model(self._config(), path, content, type, format))
 
-        return _run_sync_in_new_thread(get_async)
+        return _run_sync(get_async)
 
     @gen.coroutine
     def save(self, model, path):
         with (yield self.write_lock.acquire()):
-            return (yield _save(self._config(), model, path))
+            return (yield _save_model(self._config(), model, path))
 
     @gen.coroutine
     def delete(self, path):
@@ -94,12 +94,12 @@ class CortxJupyter(ContentsManager):
     @gen.coroutine
     def update(self, model, path):
         with (yield self.write_lock.acquire()):
-            return (yield _rename(self._config(), path, model['path']))
+            return (yield _rename_notebook(self._config(), path, model['path']))
 
     @gen.coroutine
     def new_untitled(self, path='', type='', ext=''):
         with (yield self.write_lock.acquire()):
-            return (yield _new_untitled(self._config(), path, type, ext))
+            return (yield _new_untitled_notebook(self._config(), path, type, ext))
 
     @gen.coroutine
     def new(self, model, path):
@@ -114,7 +114,7 @@ class CortxJupyter(ContentsManager):
     @gen.coroutine
     def create_checkpoint(self, path):
         with (yield self.write_lock.acquire()):
-            return (yield _create_checkpoint(self._config(), path))
+            return (yield _create_new_checkpoint(self._config(), path))
 
     @gen.coroutine
     def restore_checkpoint(self, checkpoint_id, path):
@@ -123,7 +123,7 @@ class CortxJupyter(ContentsManager):
 
     @gen.coroutine
     def list_checkpoints(self, path):
-        return (yield _list_checkpoints(self._config(), path))
+        return (yield _list_all_checkpoints(self._config(), path))
 
     @gen.coroutine
     def delete_checkpoint(self, checkpoint_id, path):
